=======
History
=======

0.61.0 (2023-06-13)
-------------------

* See release notes and changelog on GitHub: https://github.com/projectnessie/nessie/releases/tag/nessie-0.61.0

0.60.1 (2023-05-25)
-------------------

* See release notes and changelog on GitHub: https://github.com/projectnessie/nessie/releases/tag/nessie-0.60.1

0.60.0 (2023-05-25)
-------------------

* See release notes and changelog on GitHub: https://github.com/projectnessie/nessie/releases/tag/nessie-0.60.0

0.59.0 (2023-05-18)
-------------------

* See release notes and changelog on GitHub: https://github.com/projectnessie/nessie/releases/tag/nessie-0.59.0

0.58.1 (2023-04-19)
-------------------

* See release notes and changelog on GitHub: https://github.com/projectnessie/nessie/releases/tag/nessie-0.58.1

0.58.0 (2023-04-15)
-------------------

* See release notes and changelog on GitHub: https://github.com/projectnessie/nessie/releases/tag/nessie-0.58.0

0.57.0 (2023-04-11)
-------------------

* See release notes and changelog on GitHub: https://github.com/projectnessie/nessie/releases/tag/nessie-0.57.0

0.56.0 (2023-04-05)
-------------------

* See release notes and changelog on GitHub: https://github.com/projectnessie/nessie/releases/tag/nessie-0.56.0

0.55.0 (2023-04-04)
-------------------

* See release notes and changelog on GitHub: https://github.com/projectnessie/nessie/releases/tag/nessie-0.55.0

0.54.0 (2023-03-30)
-------------------

* See release notes and changelog on GitHub: https://github.com/projectnessie/nessie/releases/tag/nessie-0.54.0

0.53.1 (2023-03-24)
-------------------

* See release notes and changelog on GitHub: https://github.com/projectnessie/nessie/releases/tag/nessie-0.53.1

0.53.0 (2023-03-23)
-------------------

* See release notes and changelog on GitHub: https://github.com/projectnessie/nessie/releases/tag/nessie-0.53.0

0.52.3 (2023-03-20)
-------------------

* See release notes and changelog on GitHub: https://github.com/projectnessie/nessie/releases/tag/nessie-0.52.3

0.52.2 (2023-03-20)
-------------------

* See release notes and changelog on GitHub: https://github.com/projectnessie/nessie/releases/tag/nessie-0.52.2

0.52.1 (2023-03-20)
-------------------

* See release notes and changelog on GitHub: https://github.com/projectnessie/nessie/releases/tag/nessie-0.52.1

0.52.0 (2023-03-20)
-------------------

* See release notes and changelog on GitHub: https://github.com/projectnessie/nessie/releases/tag/nessie-0.52.0

0.51.1 (2023-03-07)
-------------------

* See release notes and changelog on GitHub: https://github.com/projectnessie/nessie/releases/tag/nessie-0.51.1

0.51.0 (2023-03-06)
-------------------

* See release notes and changelog on GitHub: https://github.com/projectnessie/nessie/releases/tag/nessie-0.51.0

0.50.0 (2023-02-24)
-------------------

* See release notes and changelog on GitHub: https://github.com/projectnessie/nessie/releases/tag/nessie-0.50.0

0.49.0 (2023-02-17)
-------------------

* See release notes and changelog on GitHub: https://github.com/projectnessie/nessie/releases/tag/nessie-0.49.0

0.48.2 (2023-02-08)
-------------------

* See release notes and changelog on GitHub: https://github.com/projectnessie/nessie/releases/tag/nessie-0.48.2

0.48.1 (2023-02-06)
-------------------

* See release notes and changelog on GitHub: https://github.com/projectnessie/nessie/releases/tag/nessie-0.48.1

0.48.0 (2023-02-06)
-------------------

* See release notes and changelog on GitHub: https://github.com/projectnessie/nessie/releases/tag/nessie-0.48.0

0.47.1 (2023-01-20)
-------------------

* See release notes and changelog on GitHub: https://github.com/projectnessie/nessie/releases/tag/nessie-0.47.1

0.47.0 (2023-01-18)
-------------------

* See release notes and changelog on GitHub: https://github.com/projectnessie/nessie/releases/tag/nessie-0.47.0

0.46.7 (2023-01-12)
-------------------

* See release notes and changelog on GitHub: https://github.com/projectnessie/nessie/releases/tag/nessie-0.46.7

0.46.5 (2023-01-12)
-------------------

* See release notes and changelog on GitHub: https://github.com/projectnessie/nessie/releases/tag/nessie-0.46.5

0.46.3 (2023-01-06)
-------------------

* See release notes and changelog on GitHub: https://github.com/projectnessie/nessie/releases/tag/nessie-0.46.3

0.46.2 (2022-12-28)
-------------------

* See release notes and changelog on GitHub: https://github.com/projectnessie/nessie/releases/tag/nessie-0.46.2
* Python: Fix CI build failure because of tox error (#5749)

0.46.0 (2022-12-20)
-------------------

* See release notes and changelog on GitHub: https://github.com/projectnessie/nessie/releases/tag/nessie-0.46.0
* python: upgrade safety to 2.3.4 (#5658)

0.45.0 (2022-11-29)
-------------------

* See release notes and changelog on GitHub: https://github.com/projectnessie/nessie/releases/tag/nessie-0.45.0
* python: ignore unimportant CVE to fix linting (#5525)
* python: fix lint with new mypy version (#5480)
* Record next development version (#5387)

0.44.0 (2022-10-18)
-------------------

* See release notes and changelog on GitHub: https://github.com/projectnessie/nessie/releases/tag/nessie-0.44.0
* Upgrade desert to 2022.9.22 (#5345)

0.43.0 (2022-09-15)
-------------------

* Configurable timeout of HTTP calls to Nessie (defaults to 60 seconds)
* Fix default behaviour for transplant in CLI
* Handle merge response in CLI
* Fix key list lookup with hash collisions

0.42.0 (2022-08-26)
-------------------

* (No Python related highlights)

0.41.0 (2022-08-05)
-------------------

* (No Python related highlights)

0.40.3 (2022-08-01)
-------------------

* (No Python related highlights)

0.40.2 (2022-08-01)
-------------------

* (No Python related highlights)

0.40.1 (2022-07-25)
-------------------

* (No Python related highlights)

0.40.0 (2022-07-22)
-------------------

* Change Pynessie dependencies import from relative to absolute
* Use isort instead of flake8-import-order

0.30.0 (2022-05-13)
-------------------

* (No Python related highlights)

0.29.0 (2022-05-05)
-------------------

* (No Python related highlights)

0.28.0 (2022-04-26)
-------------------

* (No Python related highlights)

0.27.0 (2022-04-14)
-------------------

* (No Python related highlights)

0.26.0 (2022-04-12)
-------------------

* (No Python related highlights)

0.25.0 (2022-04-06)
-------------------

* (No Python related highlights)

0.24.0 (2022-03-31)
-------------------

* (No Python related highlights)

0.23.1 (2022-03-23)
-------------------

* (No Python related highlights)

0.23.0 (2022-03-23)
-------------------

* (not released)

0.22.0 (2022-03-11)
-------------------

* (No Python related highlights)

0.21.2 (2022-03-02)
-------------------

* (No Python related highlights)

0.21.1 (2022-03-02)
-------------------

* (No Python related highlights)

0.21.0 (2022-03-01)
-------------------

* (No Python related highlights)

0.20.1 (2022-02-17)
-------------------

* (No Python related highlights)

0.20.0 (2022-02-16)
-------------------

* (No Python related highlights)

0.19.0 (2022-02-07)
-------------------

* Reads using "detached" commit-ids w/o specifying a branch or tag name
* Support for Iceberg views (experimental)

0.18.0 (2022-01-13)
-------------------

* Add new reflog command to the CLI
* Add support for Python 3.10
* Drop support for Python 3.6

0.17.0 (2021-12-08)
-------------------

* Rename --query/--query-expression flag to --filter

0.16.0 (2021-12-03)
-------------------

* Add -x flag to fetch additional metadata for branches/tags
* Add diff command to show the diff between two references

0.15.1 (2021-12-01)
-------------------

* no changes for Python

0.15.0 (2021-12-01)
-------------------

* Enhance commit log to optionally return original commit operations

0.14.0 (2021-11-12)
-------------------

* Updated 'IcebergTable' to track more information
* Better 'ContentKey' handling
* Nessie CLI code cleanups

0.12.1 (2021-11-03)
-------------------

* Update / clarify CLI docs
* Fix 'pynessie.auth' not found error
* Clearer 'nessie log' cli command

0.12.0 (2021-10-25)
-------------------

* Specialize and document Nessie exceptions
* Fix --json on specific branches and tags

0.11.0 (2021-10-20)
-------------------

* Fix Nessie's representation of global and on-reference state (Iceberg tables)
* Support expected contents in Nessie Put operations in CLI
* Fix CLI log -n option

0.10.1 (2021-10-08)
-------------------

* Various fixes and improvements
* Update REST-API calls for new version-store API requirements

0.9.2 (2021-08-26)
------------------

* (No Python related highlights)

0.9.0 (2021-08-09)
------------------

* (No Python related highlights)

0.8.3 (2021-07-19)
------------------

* Fix ser/de of SqlView when listing contents

0.8.2 (2021-07-15)
------------------

* REST-API change: only accept named-references
* REST-API change: Server-side commit range filtering
* OpenAPI: more explicit constraints on parameters
* Commit-log filtering on all fields of CommitMeta
* Use "Common Expression Language" for commit-log and entries filtering
* Prepare for multi-tenancy
* Fix ser/de of DeltaLakeTable when listing contents

0.7.0 (2021-06-15)
------------------

* Fix naming in nessie client merge operation
* Distinguish between author & committer in the Python CLI
* Allow setting author when committing via Python CLI
* Loosen pins for client install on Python cli

0.6.1 (2021-05-25)
------------------

(no Python relevant changes)

0.6.0 (2021-05-12)
------------------

* create-reference and commit operations return the new commit-hash
* dependency updates

0.5.1 (2021-04-09)
------------------

(no Python relevant changes)

0.5.0 (2021-04-08)
------------------

* dependency updates
* endpoint updates for object type and new commit metadata object

0.4.0 (2021-03-08)
------------------

* dependency updates

0.3.0 (2020-12-30)
------------------

* support for python3.9
* correct display of contents in the cli
* better type checking

0.2.1 (2020-10-30)
------------------

* fix install requirements in setup.py

0.2.0 (2020-10-30)
------------------

* git-like cli interface
* more complete coverage of REST endpoints
* better testing

0.1.1 (2020-10-01)
------------------

* First release on PyPI.
